@@ -299,15 +299,15 @@ class Capabilities:
 	# noinspection PyTypeChecker
 	class RlpInfoStruct(StructBase):
 		"""Structure for reading output parameters. Fields: \n
-			- Bit_Count_Info: str: Information bit count. Range: #H0 to #HF423F
+			- Bitcount_Info: str: Information bit count. Range: #H0 to #HF423F
 			- Protocol_Info: str: Protocol information."""
 		__meta_args_list = [
-			ArgStruct.scalar_raw_str('Bit_Count_Info'),
+			ArgStruct.scalar_raw_str('Bitcount_Info'),
 			ArgStruct.scalar_str('Protocol_Info')]
 
 		def __init__(self):
 			StructBase.__init__(self, self)
-			self.Bit_Count_Info: str = None
+			self.Bitcount_Info: str = None
 			self.Protocol_Info: str = None
 
 	def get_rlp_info(self) -> RlpInfoStruct:
