@@ -11,9 +11,9 @@ class Fch:
 		self._core = core
 		self._base = CommandsGroup("fch", core, parent)
 
-	def get_freq_offset(self) -> int:
+	def get_foffset(self) -> int:
 		"""SCPI: CONFigure:CDMA:SIGNaling<Instance>:LAYer:FCH:FOFFset \n
-		Snippet: value: int = driver.configure.layer.fch.get_freq_offset() \n
+		Snippet: value: int = driver.configure.layer.fch.get_foffset() \n
 		Sets the frame offset in the forward fundamental channel. Changing the frame offset immediately changes the traffic
 		channel timing. \n
 			:return: frame_offset: Range: 0 to 15
@@ -21,9 +21,9 @@ class Fch:
 		response = self._core.io.query_str('CONFigure:CDMA:SIGNaling<Instance>:LAYer:FCH:FOFFset?')
 		return Conversions.str_to_int(response)
 
-	def set_freq_offset(self, frame_offset: int) -> None:
+	def set_foffset(self, frame_offset: int) -> None:
 		"""SCPI: CONFigure:CDMA:SIGNaling<Instance>:LAYer:FCH:FOFFset \n
-		Snippet: driver.configure.layer.fch.set_freq_offset(frame_offset = 1) \n
+		Snippet: driver.configure.layer.fch.set_foffset(frame_offset = 1) \n
 		Sets the frame offset in the forward fundamental channel. Changing the frame offset immediately changes the traffic
 		channel timing. \n
 			:param frame_offset: Range: 0 to 15
