@@ -11,20 +11,20 @@ class Tdata:
 		self._base = CommandsGroup("tdata", core, parent)
 
 	@property
-	def ferfch(self):
-		"""ferfch commands group. 1 Sub-classes, 3 commands."""
-		if not hasattr(self, '_ferfch'):
-			from .Tdata_.Ferfch import Ferfch
-			self._ferfch = Ferfch(self._core, self._base)
-		return self._ferfch
+	def ferfCh(self):
+		"""ferfCh commands group. 1 Sub-classes, 3 commands."""
+		if not hasattr(self, '_ferfCh'):
+			from .Tdata_.FerfCh import FerfCh
+			self._ferfCh = FerfCh(self._core, self._base)
+		return self._ferfCh
 
 	@property
-	def fersch(self):
-		"""fersch commands group. 1 Sub-classes, 3 commands."""
-		if not hasattr(self, '_fersch'):
-			from .Tdata_.Fersch import Fersch
-			self._fersch = Fersch(self._core, self._base)
-		return self._fersch
+	def fersCh(self):
+		"""fersCh commands group. 1 Sub-classes, 3 commands."""
+		if not hasattr(self, '_fersCh'):
+			from .Tdata_.FersCh import FersCh
+			self._fersCh = FersCh(self._core, self._base)
+		return self._fersCh
 
 	def clone(self) -> 'Tdata':
 		"""Clones the group by creating new object from it and its whole existing sub-groups
